@@ -1,3 +1,5 @@
+#!/bin/bash
+
 type getarg >/dev/null 2>&1 || . /lib/dracut-lib.sh
 type udev_pending >/dev/null 2>&1 || . /lib/kiwi-lib.sh
 
@@ -20,7 +22,11 @@ function create_partitions {
             create_dasd_partitions "${disk_device}" "${partition_setup}"
         ;;
     esac
-    partprobe "${disk_device}"
+    if type partprobe &> /dev/null;then
+        partprobe "${disk_device}"
+    else
+        blockdev --rereadpt "${disk_device}"
+    fi
 }
 
 function create_msdos_partitions {
@@ -137,6 +143,13 @@ function create_dasd_partitions {
     local ignore_cmd=0
     local ignore_cmd_once=0
     local cmd
+
+    # We resize first partition to enfore rewrite of the current
+    # partition table updated to the actual disk geometry. This is
+    # to circumvent the fdasd limitation of not being capable to
+    # expand the partition table up to the disk size bsc#1209247
+    parted --script --machine "${disk_device}" resizepart 1
+
     for cmd in ${partition_setup};do
         if [ "${ignore_cmd}" = 1 ] && echo "${cmd}" | grep -qE '[dntwq]';then
             ignore_cmd=0
@@ -278,7 +291,15 @@ function get_free_disk_bytes {
 }
 
 function get_partition_table_type {
-    blkid -s PTTYPE -o value "$1"
+    local disk_device="$1"
+
+    # blkid doesn't work for dasd partitions, so on s390 parted is used
+    # to detect the partition type (bsc#1209247)
+    if [[ "$(uname -m)" =~ s390 ]];then
+        parted --script --machine "${disk_device}" print | grep "^${disk_device}" | cut -d":" -f6
+    else
+        blkid -s PTTYPE -o value "$disk_device"
+    fi
 }
 
 function get_partition_uuid {
