@@ -124,6 +124,8 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
             Defaults.get_volume_id()
         self.install_volid = self.xml_state.build_type.get_volid() or \
             Defaults.get_install_volume_id()
+        self.use_disk_password = \
+            self.xml_state.get_build_type_bootloader_use_disk_password()
 
         self.live_boot_options = [
             'root=live:CDLABEL={0}'.format(self.volume_id),
@@ -231,14 +233,18 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
                 'root_device': string,
                 'boot_device': string,
                 'efi_device': string,
-                'system_volumes': volume_manager_instance.get_volumes()
+                'system_volumes':
+                    volume_manager_instance.get_volumes(),
+                'system_root_volume':
+                    volume_manager_instance.get_root_volume_name()
             }
         """
         self._mount_system(
             boot_options.get('root_device'),
             boot_options.get('boot_device'),
             boot_options.get('efi_device'),
-            boot_options.get('system_volumes')
+            boot_options.get('system_volumes'),
+            boot_options.get('system_root_volume')
         )
         config_file = os.sep.join(
             [
@@ -276,10 +282,11 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
         # More details can be found in the individual methods.
         # One fine day the following fix methods can hopefully
         # be deleted...
-        self._fix_grub_to_support_dynamic_efi_and_bios_boot(config_file)
-        self._fix_grub_root_device_reference(config_file, boot_options)
-        self._fix_grub_loader_entries_boot_cmdline()
-        self._fix_grub_loader_entries_linux_and_initrd_paths()
+        if self.xml_state.build_type.get_overlayroot_write_partition() is not False:
+            self._fix_grub_to_support_dynamic_efi_and_bios_boot(config_file)
+            self._fix_grub_root_device_reference(config_file, boot_options)
+            self._fix_grub_loader_entries_boot_cmdline()
+            self._fix_grub_loader_entries_linux_and_initrd_paths()
 
         if self.firmware.efi_mode() and self.early_boot_script_efi:
             self._copy_grub_config_to_efi_path(
@@ -348,7 +355,7 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
             )
         if self.firmware.efi_mode() and self.early_boot_script_efi:
             self._copy_grub_config_to_efi_path(
-                self.boot_dir, self.early_boot_script_efi
+                self.boot_dir, self.early_boot_script_efi, 'iso'
             )
 
     def setup_live_image_config(
@@ -412,7 +419,7 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
             )
         if self.firmware.efi_mode() and self.early_boot_script_efi:
             self._copy_grub_config_to_efi_path(
-                self.boot_dir, self.early_boot_script_efi
+                self.boot_dir, self.early_boot_script_efi, 'iso'
             )
 
     def setup_install_boot_images(self, mbrid, lookup_path=None):
@@ -451,11 +458,11 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
             self._setup_EFI_path(lookup_path)
 
         if self.firmware.efi_mode() == 'efi':
-            self._setup_efi_image(mbrid=mbrid, lookup_path=lookup_path)
+            self._setup_efi_image(mbrid=mbrid, lookup_path=lookup_path, target_type='iso')
             self._copy_efi_modules_to_boot_directory(lookup_path)
         elif self.firmware.efi_mode() == 'uefi':
             self._setup_secure_boot_efi_image(
-                lookup_path=lookup_path, mbrid=mbrid
+                lookup_path=lookup_path, mbrid=mbrid, target_type='iso'
             )
 
         log.info('--> Creating loopback config')
@@ -508,7 +515,9 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
         if self.xen_guest:
             self._copy_xen_modules_to_boot_directory(lookup_path)
 
-    def _copy_grub_config_to_efi_path(self, root_path, config_file):
+    def _copy_grub_config_to_efi_path(
+        self, root_path, config_file, target_type='disk'
+    ):
         efi_boot_path = Defaults.get_shim_vendor_directory(
             root_path
         )
@@ -517,7 +526,7 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
             # have them in their encoded early boot script. Thus
             # the following code tries to look up the vendor string
             # from the signed grub binary
-            grub_image = Defaults.get_signed_grub_loader(self.root_dir)
+            grub_image = Defaults.get_signed_grub_loader(self.root_dir, target_type)
             if grub_image and grub_image.filename:
                 bash_command = [
                     'strings', grub_image.filename, '|', 'grep', 'EFI\/'
@@ -575,6 +584,8 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
             sysconfig_bootloader_entries['TRUSTED_BOOT'] = 'yes'
         if self.firmware.efi_mode() == 'uefi':
             sysconfig_bootloader_entries['SECURE_BOOT'] = 'yes'
+        elif self.firmware.efi_mode() == 'efi':
+            sysconfig_bootloader_entries['SECURE_BOOT'] = 'no'
         if self.cmdline:
             sysconfig_bootloader_entries['DEFAULT_APPEND'] = '"{0}"'.format(
                 self.cmdline
@@ -771,7 +782,9 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
                         grub_default[key] = value
                 grub_default.write()
 
-    def _setup_secure_boot_efi_image(self, lookup_path, uuid=None, mbrid=None):
+    def _setup_secure_boot_efi_image(
+        self, lookup_path, uuid=None, mbrid=None, target_type='disk'
+    ):
         """
         Provide the shim loader and the shim signed grub2 loader
         in the required boot path. Normally this task is done by
@@ -784,11 +797,11 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
         code should act as the fallback solution
         """
         log.warning(
-            '--> Running fallback setup for shim secure boot efi image'
+            'Running fallback setup for shim secure boot efi image'
         )
         if not lookup_path:
             lookup_path = self.boot_dir
-        grub_image = Defaults.get_signed_grub_loader(lookup_path)
+        grub_image = Defaults.get_signed_grub_loader(lookup_path, target_type)
         if not grub_image:
             raise KiwiBootLoaderGrubSecureBootError(
                 'Signed grub2 efi loader not found'
@@ -800,29 +813,52 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
             # a grub image that got signed by the shim. The shim image
             # is the one that gets loaded by the firmware which itself
             # loads the second stage grub image
-            Command.run(
-                ['cp', shim_image.filename, self._get_efi_image_name()]
-            )
-            Command.run(
-                [
-                    'cp', grub_image.filename,
-                    os.sep.join([self.efi_boot_path, grub_image.binaryname])
-                ]
+            target_efi_image_name = self._get_efi_image_name()
+            target_grub_image_name = os.sep.join(
+                [self.efi_boot_path, grub_image.binaryname]
             )
+            if not os.path.isfile(target_efi_image_name):
+                log.info(
+                    f'--> Using shim image: {shim_image.filename}'
+                )
+                Command.run(
+                    ['cp', shim_image.filename, target_efi_image_name]
+                )
+            if not os.path.isfile(target_grub_image_name):
+                log.info(
+                    f'--> Using grub image: {grub_image.filename}'
+                )
+                Command.run(
+                    ['cp', grub_image.filename, target_grub_image_name]
+                )
             mok_manager = Defaults.get_mok_manager(lookup_path)
             if mok_manager:
-                Command.run(
-                    ['cp', mok_manager, self.efi_boot_path]
+                target_mok_manager = os.sep.join(
+                    [self.efi_boot_path, os.path.basename(mok_manager)]
                 )
+                if not os.path.isfile(target_mok_manager):
+                    log.info(
+                        f'--> Using mok image: {mok_manager}'
+                    )
+                    Command.run(
+                        ['cp', mok_manager, self.efi_boot_path]
+                    )
         else:
             # Without shim a self signed grub image is used that
             # gets loaded by the firmware
-            Command.run(
-                ['cp', grub_image.filename, self._get_efi_image_name()]
-            )
+            target_efi_image_name = self._get_efi_image_name()
+            if not os.path.isfile(target_efi_image_name):
+                log.info(
+                    f'--> No shim image, using grub image: {grub_image.filename}'
+                )
+                Command.run(
+                    ['cp', grub_image.filename, target_efi_image_name]
+                )
         self._create_efi_config_search(uuid, mbrid)
 
-    def _setup_efi_image(self, uuid=None, mbrid=None, lookup_path=None):
+    def _setup_efi_image(
+        self, uuid=None, mbrid=None, lookup_path=None, target_type='disk'
+    ):
         """
         Provide the unsigned grub2 efi image in the required boot path
         If a prebuilt efi image as provided by the distribution could
@@ -832,9 +868,9 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
         """
         if not lookup_path:
             lookup_path = self.boot_dir
-        grub_image = Defaults.get_unsigned_grub_loader(lookup_path)
-        if grub_image:
-            log.info('--> Using prebuilt unsigned efi image')
+        grub_image = Defaults.get_unsigned_grub_loader(lookup_path, target_type)
+        if grub_image and self.xml_state.build_type.get_overlayroot_write_partition() is not False:
+            log.info(f'--> Using prebuilt unsigned efi image: {grub_image}')
             Command.run(
                 ['cp', grub_image, self._get_efi_image_name()]
             )
@@ -853,7 +889,7 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
             lookup_path = self.boot_dir
         grub_image = Defaults.get_grub_bios_core_loader(lookup_path)
         if grub_image:
-            log.info('--> Using prebuilt bios image')
+            log.info(f'--> Using prebuilt bios image: {grub_image}')
         else:
             log.info('--> Creating bios image')
             self._create_bios_image(
@@ -1057,7 +1093,7 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
                 )
             )
             early_boot.write(
-                'configfile ($root){0}/{1}/grub.cfg{2}'.format(
+                'source ($root){0}/{1}/grub.cfg{2}'.format(
                     self.get_boot_path(), self.boot_directory_name, os.linesep
                 )
             )
@@ -1068,8 +1104,8 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
                 'set btrfs_relative_path="yes"{0}'.format(os.linesep)
             )
             early_boot.write(
-                'search --file --set=root /boot/{0}{1}'.format(
-                    mbrid.get_id(), os.linesep
+                'search --file --set=root /boot/mbrid{0}'.format(
+                    os.linesep
                 )
             )
             early_boot.write(
@@ -1078,7 +1114,7 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
                 )
             )
             early_boot.write(
-                'configfile ($root)/boot/{0}/grub.cfg{1}'.format(
+                'source ($root)/boot/{0}/grub.cfg{1}'.format(
                     self.boot_directory_name, os.linesep
                 )
             )
