@@ -126,6 +126,8 @@ class DiskBuilder:
         self.hybrid_mbr = xml_state.build_type.get_gpt_hybrid_mbr()
         self.force_mbr = xml_state.build_type.get_force_mbr()
         self.luks = xml_state.get_luks_credentials()
+        self.use_disk_password = \
+            xml_state.get_build_type_bootloader_use_disk_password()
         self.integrity_root = xml_state.build_type.get_standalone_integrity()
         self.integrity_legacy_hmac = xml_state.build_type.get_integrity_legacy_hmac()
         self.integrity_keyfile = xml_state.build_type.get_integrity_keyfile()
@@ -134,6 +136,8 @@ class DiskBuilder:
         self.root_filesystem_embed_integrity_metadata = \
             xml_state.build_type.get_embed_integrity_metadata()
         self.luks_format_options = xml_state.get_luks_format_options()
+        self.luks_randomize = \
+            xml_state.build_type.get_luks_randomize() or True
         self.luks_os = xml_state.build_type.get_luksOS()
         self.xen_server = xml_state.is_xen_server()
         self.requested_filesystem = xml_state.build_type.get_filesystem()
@@ -144,6 +148,8 @@ class DiskBuilder:
         self.target_removable = xml_state.build_type.get_target_removable()
         self.root_filesystem_is_multipath = \
             xml_state.get_oemconfig_oem_multipath_scan()
+        self.btrfs_set_default_volume = \
+            xml_state.build_type.get_btrfs_set_default_volume()
         self.oem_systemsize = xml_state.get_oemconfig_oem_systemsize()
         self.oem_resize = xml_state.get_oemconfig_oem_resize()
         self.disk_resize_requested = \
@@ -347,7 +353,7 @@ class DiskBuilder:
         luks_root = None
         if self.luks is not None:
             luks_root = LuksDevice(device_map['root'])
-            self.luks_boot_keyname = '/.root.keyfile'
+            self.luks_boot_keyname = '/root/.root.keyfile'
             self.luks_boot_keyfile = ''.join(
                 [self.root_dir, self.luks_boot_keyname]
             )
@@ -366,9 +372,11 @@ class DiskBuilder:
                 True if self.boot_is_crypto or self.luks == '' else False
             luks_root.create_crypto_luks(
                 passphrase=self.luks,
-                os=self.luks_os,
+                osname=self.luks_os,
                 options=self.luks_format_options,
-                keyfile=self.luks_boot_keyfile if luks_need_keyfile else ''
+                keyfile=self.luks_boot_keyname if luks_need_keyfile else '',
+                randomize=self.luks_randomize,
+                root_dir=self.root_dir
             )
             if luks_need_keyfile:
                 self.luks_boot_keyfile_setup = ''.join(
@@ -379,7 +387,7 @@ class DiskBuilder:
                     config_file=self.luks_boot_keyfile_setup
                 )
                 self.boot_image.include_file(
-                    os.sep + os.path.basename(self.luks_boot_keyfile)
+                    '/root/' + os.path.basename(self.luks_boot_keyfile)
                 )
             device_map['luks_root'] = device_map['root']
             device_map['root'] = luks_root.get_device()
@@ -411,6 +419,11 @@ class DiskBuilder:
                 'root_is_readonly_snapshot':
                     self.xml_state.build_type.
                     get_btrfs_root_is_readonly_snapshot(),
+                'root_is_subvolume':
+                    self.xml_state.build_type.
+                    get_btrfs_root_is_subvolume(),
+                'set_default_volume':
+                    self.btrfs_set_default_volume,
                 'quota_groups':
                     self.xml_state.build_type.get_btrfs_quota_groups(),
                 'resize_on_boot':
@@ -517,7 +530,9 @@ class DiskBuilder:
         # create second stage metadata to system image
         self._copy_first_boot_files_to_system_image()
 
-        self._write_bootloader_meta_data_to_system_image(device_map, disk)
+        self._write_bootloader_meta_data_to_system_image(
+            device_map, disk, system
+        )
 
         self.mbrid.write_to_disk(
             disk.storage_provider
@@ -1006,7 +1021,7 @@ class DiskBuilder:
             log.info('--> setting active flag to primary PReP partition')
             disk.activate_boot_partition()
 
-        if not self.firmware.efi_mode() and self.disk_start_sector:
+        if self.firmware.get_partition_table_type() == 'msdos' and self.disk_start_sector:
             log.info(f'--> setting start sector to: {self.disk_start_sector}')
             disk.set_start_sector(self.disk_start_sector)
 
@@ -1110,6 +1125,13 @@ class DiskBuilder:
             custom_root_mount_args += ['ro']
             fs_check_interval = '0 0'
 
+        if self.volume_manager_name and self.volume_manager_name == 'btrfs':
+            root_volume_name = system.get_root_volume_name()
+            if root_volume_name != '/':
+                custom_root_mount_args += [
+                    f'defaults,subvol={root_volume_name}'
+                ]
+
         self._add_fstab_entry(
             device_map['root'].get_device(), '/',
             custom_root_mount_args, fs_check_interval
@@ -1228,13 +1250,20 @@ class DiskBuilder:
             )
 
     def _write_bootloader_meta_data_to_system_image(
-        self, device_map: Dict, disk: Disk
+        self, device_map: Dict, disk: Disk, system: Any
     ) -> None:
         if self.bootloader != 'custom':
             log.info('Creating %s bootloader configuration', self.bootloader)
             boot_options = []
             if self.mdraid:
                 boot_options.append('rd.auto')
+            if self.volume_manager_name \
+               and self.volume_manager_name == 'btrfs' \
+               and self.btrfs_set_default_volume is False \
+               and system.get_root_volume_name() != '/':
+                boot_options.append(
+                    f'rootflags=subvol={system.get_root_volume_name()}'
+                )
             ro_device = device_map.get('readonly')
             root_device = device_map['root']
             boot_device = root_device
@@ -1518,7 +1547,12 @@ class DiskBuilder:
         if self.volume_manager_name:
             system.umount_volumes()
             custom_install_arguments.update(
-                {'system_volumes': system.get_volumes()}
+                {
+                    'system_volumes': system.get_volumes(),
+                    'system_root_volume':
+                        system.get_root_volume_name()
+                        if self.volume_manager_name == 'btrfs' else None
+                }
             )
 
         if self.bootloader != 'custom':
@@ -1533,17 +1567,25 @@ class DiskBuilder:
                 # cleanup bootloader config resources taken prior to next steps
                 del self.bootloader_config
 
-            log.debug(
-                "custom arguments for bootloader installation %s",
-                custom_install_arguments
-            )
-            bootloader = BootLoaderInstall.new(
-                self.bootloader, self.root_dir, disk.storage_provider,
-                custom_install_arguments
-            )
-            if bootloader.install_required():
-                bootloader.install()
-            bootloader.secure_boot_install()
+            if self.root_filesystem_has_write_partition is not False:
+                log.debug(
+                    "custom arguments for bootloader installation %s",
+                    custom_install_arguments
+                )
+                bootloader = BootLoaderInstall.new(
+                    self.bootloader, self.root_dir, disk.storage_provider,
+                    custom_install_arguments
+                )
+                if bootloader.install_required():
+                    bootloader.install()
+                bootloader.secure_boot_install()
+
+                if self.use_disk_password and self.luks:
+                    bootloader.set_disk_password(self.luks)
+            else:
+                log.warning(
+                    'No install of bootcode on read-only root possible'
+                )
 
         self.system_setup.call_edit_boot_install_script(
             self.diskname, boot_device.get_device()
