@@ -167,6 +167,8 @@ class LiveImageBuilder:
             self.boot_image.boot_root_directory, self.media_dir.name,
             bootloader_config.get_boot_theme()
         )
+        if self.firmware.bios_mode():
+            Iso(self.media_dir.name).setup_isolinux_boot_path()
         bootloader_config.write_meta_data()
         bootloader_config.setup_live_image_config(
             mbrid=self.mbrid
@@ -276,6 +278,7 @@ class LiveImageBuilder:
             container_image.name
         )
         Path.create(self.media_dir.name + '/LiveOS')
+        os.chmod(container_image.name, 0o644)
         shutil.copy(
             container_image.name, self.media_dir.name + '/LiveOS/squashfs.img'
         )
@@ -365,6 +368,7 @@ class LiveImageBuilder:
 
         # Move initrd to iso filesystem structure
         if os.path.exists(self.boot_image.initrd_filename):
+            os.chmod(self.boot_image.initrd_filename, 0o644)
             shutil.move(
                 self.boot_image.initrd_filename, boot_path + '/initrd'
             )
