@@ -626,6 +626,7 @@ class Defaults:
             'all_video',
             'xfs',
             'btrfs',
+            'squash4',
             'lvm',
             'luks',
             'gcry_rijndael',
@@ -804,14 +805,16 @@ class Defaults:
         )
 
         shim_file_patterns = [
+            shim_pattern_type('/usr/lib/shim/shim*.efi.signed.latest', 'shimx64.efi'),
             shim_pattern_type('/usr/lib/shim/shim*.efi.signed', 'shimx64.efi'),
             shim_pattern_type('/usr/share/efi/*/shim.efi', None),
             shim_pattern_type('/usr/lib64/efi/shim.efi', None),
-            shim_pattern_type('/boot/efi/EFI/*/shim*.efi', None),
+            shim_pattern_type('/boot/efi/EFI/*/shim[a-z]*.efi', None),
+            shim_pattern_type('/boot/efi/EFI/*/shim.efi', None),
             shim_pattern_type('/usr/lib/shim/shim*.efi', None)
         ]
         for shim_file_pattern in shim_file_patterns:
-            for shim_file in glob.iglob(root_path + shim_file_pattern.pattern):
+            for shim_file in sorted(glob.iglob(root_path + shim_file_pattern.pattern), key=len):
                 if not shim_file_pattern.binaryname:
                     binaryname = os.path.basename(shim_file)
                 else:
@@ -866,12 +869,14 @@ class Defaults:
                 return font_dir
 
     @staticmethod
-    def get_unsigned_grub_loader(root_path):
+    def get_unsigned_grub_loader(
+        root_path: str, target_type: str = 'disk'
+    ) -> Optional[str]:
         """
         Provides unsigned grub efi loader file path
 
-        Searches distribution specific locations to find grub.efi
-        below the given root path
+        Searches distribution specific locations to find a distro
+        grub EFI binary within the given root path
 
         :param string root_path: image root path
 
@@ -879,16 +884,28 @@ class Defaults:
 
         :rtype: str
         """
-        unsigned_grub_file_patterns = [
-            '/usr/share/grub*/*-efi/grub.efi',
-            '/usr/lib/grub*/*-efi/grub.efi',
-            '/boot/efi/EFI/*/grubx64.efi'
-        ]
-        for unsigned_grub_file_pattern in unsigned_grub_file_patterns:
+        unsigned_grub_file = None
+        unsigned_grub_file_patterns = {
+            'disk': [
+                '/usr/share/grub*/*-efi/grub.efi',
+                '/usr/lib/grub*/*-efi/grub.efi',
+                '/boot/efi/EFI/*/grubx64.efi',
+                '/boot/efi/EFI/*/grubaa64.efi'
+            ],
+            'iso': [
+                '/boot/efi/EFI/*/gcdx64.efi',
+                '/usr/share/grub*/*-efi/grub.efi',
+                '/usr/lib/grub*/*-efi/grub.efi',
+                '/boot/efi/EFI/*/grubx64.efi',
+                '/boot/efi/EFI/*/grubaa64.efi'
+            ]
+        }
+        for unsigned_grub_file_pattern in unsigned_grub_file_patterns[target_type]:
             for unsigned_grub_file in glob.iglob(
                 root_path + unsigned_grub_file_pattern
             ):
                 return unsigned_grub_file
+        return None
 
     @staticmethod
     def get_grub_bios_core_loader(root_path):
@@ -971,12 +988,14 @@ class Defaults:
         return 'eltorito.img'
 
     @staticmethod
-    def get_signed_grub_loader(root_path: str) -> Optional[grub_loader_type]:
+    def get_signed_grub_loader(
+        root_path: str, target_type: str = 'disk'
+    ) -> Optional[grub_loader_type]:
         """
         Provides shim signed grub loader file path
 
-        Searches distribution specific locations to find grub.efi
-        below the given root path
+        Searches distribution specific locations to find a grub
+        EFI binary within the given root path
 
         :param str root_path: image root path
 
@@ -987,25 +1006,54 @@ class Defaults:
         grub_pattern_type = namedtuple(
             'grub_pattern_type', ['pattern', 'binaryname']
         )
-        signed_grub_file_patterns = [
-            grub_pattern_type(
-                '/usr/share/efi/*/grub.efi', None
-            ),
-            grub_pattern_type(
-                '/usr/lib64/efi/grub.efi', None
-            ),
-            grub_pattern_type(
-                '/boot/efi/EFI/*/grub*.efi', None
-            ),
-            grub_pattern_type(
-                '/usr/share/grub*/*-efi/grub.efi', None
-            ),
-            grub_pattern_type(
-                '/usr/lib/grub/x86_64-efi-signed/grubx64.efi.signed',
-                'grubx64.efi'
-            )
-        ]
-        for signed_grub in signed_grub_file_patterns:
+        signed_grub_file_patterns = {
+            'disk': [
+                grub_pattern_type(
+                    '/usr/share/efi/*/grub.efi', None
+                ),
+                grub_pattern_type(
+                    '/usr/lib64/efi/grub.efi', None
+                ),
+                grub_pattern_type(
+                    '/boot/efi/EFI/*/grub*.efi', None
+                ),
+                grub_pattern_type(
+                    '/usr/share/grub*/*-efi/grub.efi', None
+                ),
+                grub_pattern_type(
+                    '/usr/lib/grub/x86_64-efi-signed/grubx64.efi.signed',
+                    'grubx64.efi'
+                )
+            ],
+            'iso': [
+                grub_pattern_type(
+                    '/boot/efi/EFI/*/gcdx64.efi',
+                    'grubx64.efi'
+                ),
+                grub_pattern_type(
+                    '/boot/efi/EFI/*/gcdaa64.efi',
+                    'grubaa64.efi'
+                ),
+                grub_pattern_type(
+                    '/usr/share/efi/*/grub.efi', None
+                ),
+                grub_pattern_type(
+                    '/usr/lib64/efi/grub.efi', None
+                ),
+                grub_pattern_type(
+                    '/boot/efi/EFI/*/grub*.efi', None
+                ),
+                grub_pattern_type(
+                    '/usr/share/grub*/*-efi/grub.efi', None
+                ),
+                grub_pattern_type(
+                    '/usr/lib/grub/x86_64-efi-signed/grubx64.efi.signed',
+                    'grubx64.efi'
+                )
+
+            ]
+        }
+        for signed_grub in signed_grub_file_patterns[target_type]:
             for signed_grub_file in glob.iglob(root_path + signed_grub.pattern):
                 if not signed_grub.binaryname:
                     binaryname = os.path.basename(signed_grub_file)
@@ -1423,7 +1471,7 @@ class Defaults:
 
         :rtype: list
         """
-        return ['tbz']
+        return ['tbz', 'cpio']
 
     @staticmethod
     def get_container_image_types():
@@ -1822,7 +1870,7 @@ class Defaults:
 
         :rtype: str
         """
-        return 'dnf'
+        return 'dnf4'
 
     @staticmethod
     def get_default_packager_tool(package_manager):
@@ -1835,7 +1883,7 @@ class Defaults:
 
         :rtype: str
         """
-        rpm_based = ['zypper', 'dnf', 'microdnf']
+        rpm_based = ['zypper', 'dnf4', 'dnf5', 'microdnf']
         deb_based = ['apt']
         if package_manager in rpm_based:
             return 'rpm'
