@@ -25,8 +25,6 @@ from xml.dom import minidom
 from typing import List
 
 # project
-import kiwi.defaults as defaults
-
 from kiwi.command import Command
 from kiwi.volume_manager.base import VolumeManagerBase
 from kiwi.mount_manager import MountManager
@@ -69,22 +67,41 @@ class VolumeManagerBtrfs(VolumeManagerBase):
             self.custom_args['root_label'] = 'ROOT'
         if 'root_is_snapshot' not in self.custom_args:
             self.custom_args['root_is_snapshot'] = False
+        if 'set_default_volume' not in self.custom_args:
+            self.custom_args['set_default_volume'] = True
         if 'root_is_readonly_snapshot' not in self.custom_args:
             self.custom_args['root_is_readonly_snapshot'] = False
+        if 'root_is_subvolume' not in self.custom_args:
+            self.custom_args['root_is_subvolume'] = None
         if 'quota_groups' not in self.custom_args:
             self.custom_args['quota_groups'] = False
 
+        self.root_volume_name = '/'
+        self.default_volume_name = self.root_volume_name
+        if self._has_root_volume():
+            self.root_volume_name = '@'
+            canonical_volume_list = self.get_canonical_volume_list()
+            for volume in canonical_volume_list.volumes:
+                if volume.is_root_volume and volume.name:
+                    self.root_volume_name = volume.name
+                    self.default_volume_name = self.root_volume_name
+
+        if self.custom_args['root_is_snapshot'] and \
+           self.root_volume_name == '/':
+            log.warning('root_is_snapshot requires a toplevel sub-volume')
+            log.warning('root_is_snapshot has been disabled')
+            self.custom_args['root_is_snapshot'] = False
+
         self.subvol_mount_list = []
         self.toplevel_mount = None
-        self.toplevel_volume = None
 
     def setup(self, name=None):
         """
         Setup btrfs volume management
 
-        In case of btrfs a toplevel(@) subvolume is created and marked
+        In case of btrfs an optional toplevel subvolume is created and marked
         as default volume. If snapshots are activated via the custom_args
-        the setup method also created the @/.snapshots/1/snapshot
+        the setup method also creates the .snapshots/1/snapshot
         subvolumes. There is no concept of a volume manager name, thus
         the name argument is not used for btrfs
 
@@ -112,31 +129,51 @@ class VolumeManagerBtrfs(VolumeManagerBase):
             Command.run(
                 ['btrfs', 'quota', 'enable', self.mountpoint]
             )
-        root_volume = self.mountpoint + '/@'
-        Command.run(
-            ['btrfs', 'subvolume', 'create', root_volume]
-        )
+        if self.root_volume_name != '/':
+            root_volume = self.mountpoint + f'/{self.root_volume_name}'
+            Command.run(
+                ['btrfs', 'subvolume', 'create', root_volume]
+            )
         if self.custom_args['root_is_snapshot']:
-            snapshot_volume = self.mountpoint + '/@/.snapshots'
+            snapshot_volume = self.mountpoint + \
+                f'/{self.root_volume_name}/.snapshots'
             Command.run(
                 ['btrfs', 'subvolume', 'create', snapshot_volume]
             )
             os.chmod(snapshot_volume, 0o700)
             Path.create(snapshot_volume + '/1')
-            snapshot = self.mountpoint + '/@/.snapshots/1/snapshot'
+            snapshot = self.mountpoint + \
+                f'/{self.root_volume_name}/.snapshots/1/snapshot'
             Command.run(
                 ['btrfs', 'subvolume', 'create', snapshot]
             )
-            self._set_default_volume('@/.snapshots/1/snapshot')
-            snapshot = self.mountpoint + '/@/.snapshots/1/snapshot'
-            # Mount /@/.snapshots as /.snapshots inside the root
+            self._set_default_volume(
+                f'{self.root_volume_name}/.snapshots/1/snapshot'
+            )
+            snapshot = self.mountpoint + \
+                f'/{self.root_volume_name}/.snapshots/1/snapshot'
+            # Mount /{some-name}/.snapshots as /.snapshots inside the root
             snapshots_mount = MountManager(
                 device=self.device,
+                attributes={
+                    'subvol_path': f'{self.root_volume_name}/.snapshots',
+                    'subvol_name': f'{self.root_volume_name}/.snapshots'
+                },
                 mountpoint=snapshot + '/.snapshots'
             )
             self.subvol_mount_list.append(snapshots_mount)
-        else:
-            self._set_default_volume('@')
+        elif self.root_volume_name != '/':
+            self._set_default_volume(self.root_volume_name)
+
+    def get_root_volume_name(self) -> str:
+        """
+        Provides name of the root volume
+
+        :return: directory path name
+
+        :rtype: string
+        """
+        return self.default_volume_name
 
     def create_volumes(self, filesystem_name):
         """
@@ -163,35 +200,67 @@ class VolumeManagerBtrfs(VolumeManagerBase):
 
         for volume in canonical_volume_list.volumes:
             if volume.is_root_volume:
-                # the btrfs root volume named '@' has been created as
+                # the btrfs root volume has been created as
                 # part of the setup procedure
                 pass
             else:
                 log.info('--> sub volume %s', volume.realpath)
-                toplevel = self.mountpoint + '/@/'
-                volume_parent_path = os.path.normpath(
-                    toplevel + os.path.dirname(volume.realpath)
+                toplevel = os.path.normpath(
+                    self.mountpoint + os.sep + self.root_volume_name
+                )
+                if volume.parent:
+                    toplevel = os.path.normpath(
+                        self.mountpoint + os.sep + volume.parent
+                    )
+
+                Path.create(
+                    os.path.dirname(
+                        os.path.normpath(toplevel + os.sep + volume.realpath)
+                    )
                 )
-                if not os.path.exists(volume_parent_path):
-                    Path.create(volume_parent_path)
                 Command.run(
                     [
                         'btrfs', 'subvolume', 'create',
-                        os.path.normpath(toplevel + volume.realpath)
+                        os.path.normpath(toplevel + os.sep + volume.realpath)
                     ]
                 )
                 self.apply_attributes_on_volume(
                     toplevel, volume
                 )
+
+                volume_mountpoint = toplevel
+
+                attributes = {
+                    'parent': volume.parent or '',
+                    'subvol_path': os.path.normpath(
+                        toplevel.replace(
+                            self.mountpoint, ''
+                        ) + os.sep + volume.realpath
+                    ).lstrip(os.sep),
+                    'subvol_name': volume.name
+                }
                 if self.custom_args['root_is_snapshot']:
-                    snapshot = self.mountpoint + '/@/.snapshots/1/snapshot/'
-                    volume_mount = MountManager(
-                        device=self.device,
-                        mountpoint=os.path.normpath(snapshot + volume.realpath)
-                    )
-                    self.subvol_mount_list.append(
-                        volume_mount
+                    volume_mountpoint = self.mountpoint + \
+                        f'/{self.root_volume_name}/.snapshots/1/snapshot/'
+                    attributes = {
+                        'subvol_path': os.path.normpath(
+                            self.root_volume_name + os.sep + volume.realpath
+                        ),
+                        'subvol_name': os.path.normpath(
+                            self.root_volume_name + os.sep + volume.realpath
+                        )
+                    }
+
+                volume_mount = MountManager(
+                    device=self.device,
+                    attributes=attributes,
+                    mountpoint=os.path.normpath(
+                        volume_mountpoint + os.sep + volume.realpath
                     )
+                )
+                self.subvol_mount_list.append(
+                    volume_mount
+                )
 
     def get_fstab(self, persistency_type='by-label', filesystem_name=None):
         """
@@ -212,14 +281,28 @@ class VolumeManagerBtrfs(VolumeManagerBase):
         blkid_type = 'LABEL' if persistency_type == 'by-label' else 'UUID'
         device_id = block_operation.get_blkid(blkid_type)
         for volume_mount in self.subvol_mount_list:
-            subvol_name = self._get_subvol_name_from_mountpoint(volume_mount)
-            mount_entry_options = mount_options + ['subvol=' + subvol_name]
+            mount_point = volume_mount.get_attributes().get('subvol_path')
+
+            # Delete root_volume_name from mountpoint path if present
+            if self.root_volume_name != '/' and \
+               mount_point.startswith(self.root_volume_name):
+                mount_point = mount_point.replace(self.root_volume_name, '')
+
+            mount_entry_options = mount_options + [
+                'subvol=' + volume_mount.get_attributes().get(
+                    'subvol_path'
+                ).lstrip(os.sep)
+            ]
+
             fs_check = self._is_volume_enabled_for_fs_check(
                 volume_mount.mountpoint
             )
             fstab_entry = ' '.join(
                 [
-                    blkid_type + '=' + device_id, subvol_name.replace('@', ''),
+                    blkid_type + '=' + device_id,
+                    mount_point if mount_point.startswith(
+                        os.sep
+                    ) else f'{os.sep}{mount_point}',
                     'btrfs', ','.join(mount_entry_options),
                     '0 {fs_passno}'.format(
                         fs_passno='2' if fs_check else '0'
@@ -239,13 +322,16 @@ class VolumeManagerBtrfs(VolumeManagerBase):
         """
         volumes = {}
         for volume_mount in self.subvol_mount_list:
-            subvol_name = self._get_subvol_name_from_mountpoint(volume_mount)
+            subvol_path = volume_mount.get_attributes().get('subvol_path')
             subvol_options = ','.join(
                 [
-                    'subvol=' + subvol_name
+                    'subvol=' + subvol_path
                 ] + self.custom_filesystem_args['mount_options']
             )
-            volumes[subvol_name.replace('@', '')] = {
+            subvol_path = subvol_path.replace(
+                self.root_volume_name, ''
+            ) if self.root_volume_name != '/' else subvol_path
+            volumes[subvol_path] = {
                 'volume_options': subvol_options,
                 'volume_device': volume_mount.device
             }
@@ -261,15 +347,18 @@ class VolumeManagerBtrfs(VolumeManagerBase):
 
         for volume_mount in self.subvol_mount_list:
             if self.volumes_mounted_initially:
+                toplevel = self.root_volume_name
+                if self.custom_args['root_is_snapshot']:
+                    toplevel = f'{self.root_volume_name}/.snapshots/1/snapshot'
                 volume_mount.mountpoint = os.path.normpath(
-                    volume_mount.mountpoint.replace(self.toplevel_volume, '', 1)
+                    volume_mount.mountpoint.replace(toplevel, '', 1)
                 )
             if not os.path.exists(volume_mount.mountpoint):
                 Path.create(volume_mount.mountpoint)
-            subvol_name = self._get_subvol_name_from_mountpoint(volume_mount)
+            subvol_path = volume_mount.get_attributes().get('subvol_path')
             subvol_options = ','.join(
                 [
-                    'subvol=' + subvol_name
+                    'subvol=' + subvol_path
                 ] + self.custom_filesystem_args['mount_options']
             )
             volume_mount.mount(
@@ -309,7 +398,9 @@ class VolumeManagerBtrfs(VolumeManagerBase):
 
         :rtype: string
         """
-        sync_target: List[str] = [self.mountpoint, '@']
+        sync_target: List[str] = [self.mountpoint]
+        if self.root_volume_name != '/':
+            sync_target.append(self.root_volume_name)
         if self.custom_args.get('root_is_snapshot'):
             sync_target.extend(['.snapshots', '1', 'snapshot'])
         return os.path.join(*sync_target)
@@ -327,7 +418,12 @@ class VolumeManagerBtrfs(VolumeManagerBase):
             sync_target = self.get_mountpoint()
             if self.custom_args['root_is_snapshot']:
                 self._create_snapshot_info(
-                    ''.join([self.mountpoint, '/@/.snapshots/1/info.xml'])
+                    ''.join(
+                        [
+                            self.mountpoint,
+                            f'/{self.root_volume_name}/.snapshots/1/info.xml'
+                        ]
+                    )
                 )
             data = DataSync(self.root_dir, sync_target)
             data.sync_data(
@@ -351,6 +447,23 @@ class VolumeManagerBtrfs(VolumeManagerBase):
                 ['btrfs', 'property', 'set', sync_target, 'ro', 'true']
             )
 
+    def _has_root_volume(self) -> bool:
+        has_root_volume = bool(self.custom_args['root_is_subvolume'])
+        if self.custom_args['root_is_subvolume'] is None:
+            # root volume not explicitly configured, will
+            # be enabled by default but this is going to change
+            # in the future. Print a deprecation message to inform
+            # the user about a potential behavior change
+            log.warning("Implicitly creating root volume")
+            log.warning(
+                "--> Future versions of kiwi will not do this anymore"
+            )
+            log.warning(
+                "--> Please specify btrfs_root_is_subvolume true|false"
+            )
+            has_root_volume = True
+        return has_root_volume
+
     def _is_volume_enabled_for_fs_check(self, mountpoint):
         for volume in self.volumes:
             if volume.realpath in mountpoint:
@@ -368,13 +481,14 @@ class VolumeManagerBtrfs(VolumeManagerBase):
                 volume_id = id_search.group(1)
                 volume_path = id_search.group(2)
                 if volume_path == default_volume:
-                    Command.run(
-                        [
-                            'btrfs', 'subvolume', 'set-default',
-                            volume_id, self.mountpoint
-                        ]
-                    )
-                    self.toplevel_volume = default_volume
+                    if self.custom_args['set_default_volume'] is not False:
+                        Command.run(
+                            [
+                                'btrfs', 'subvolume', 'set-default',
+                                volume_id, self.mountpoint
+                            ]
+                        )
+                    self.default_volume_name = default_volume
                     return
 
         raise KiwiVolumeRootIDError(
@@ -389,7 +503,12 @@ class VolumeManagerBtrfs(VolumeManagerBase):
         return xml_data_domtree.toprettyxml(indent="    ")
 
     def _create_snapper_quota_configuration(self):
-        root_path = os.sep.join([self.mountpoint, '@/.snapshots/1/snapshot'])
+        root_path = os.sep.join(
+            [
+                self.mountpoint,
+                f'{self.root_volume_name}/.snapshots/1/snapshot'
+            ]
+        )
         snapper_default_conf = Defaults.get_snapper_config_template_file(
             root_path
         )
@@ -446,15 +565,6 @@ class VolumeManagerBtrfs(VolumeManagerBase):
         with open(filename, 'w') as snapshot_info_file:
             snapshot_info_file.write(self._xml_pretty(snapshot))
 
-    def _get_subvol_name_from_mountpoint(self, volume_mount):
-        path_start_index = len(defaults.TEMP_DIR.split(os.sep)) + 1
-        subvol_name = os.sep.join(
-            volume_mount.mountpoint.split(os.sep)[path_start_index:]
-        )
-        if self.toplevel_volume and self.toplevel_volume in subvol_name:
-            subvol_name = subvol_name.replace(self.toplevel_volume, '')
-        return os.path.normpath(os.sep.join(['@', subvol_name]))
-
     def __del__(self):
         if self.toplevel_mount:
             log.info('Cleaning up %s instance', type(self).__name__)
