@@ -761,6 +761,46 @@ class TestBootLoaderConfigGrub2:
             call('TRUSTED_BOOT', 'yes')
         ]
 
+    @patch('os.path.exists')
+    @patch('kiwi.bootloader.config.grub2.SysConfig')
+    def test_setup_sysconfig_bootloader_no_secure(
+        self, mock_sysconfig, mock_exists
+    ):
+        sysconfig_bootloader = MagicMock()
+        mock_sysconfig.return_value = sysconfig_bootloader
+        mock_exists.return_value = True
+        self.bootloader._setup_sysconfig_bootloader()
+        mock_sysconfig.assert_called_once_with(
+            'root_dir/etc/sysconfig/bootloader'
+        )
+        sysconfig_bootloader.write.assert_called_once_with()
+        assert sysconfig_bootloader.__setitem__.call_args_list == [
+            call('DEFAULT_APPEND', '"some-cmdline root=UUID=foo"'),
+            call(
+                'FAILSAFE_APPEND',
+                '"some-cmdline root=UUID=foo failsafe-options"'
+            ),
+            call('LOADER_LOCATION', 'mbr'),
+            call('LOADER_TYPE', 'grub2'),
+            call('TRUSTED_BOOT', 'yes')
+        ]
+        self.firmware.efi_mode = Mock(
+            return_value='efi'
+        )
+        sysconfig_bootloader.__setitem__.reset_mock()
+        self.bootloader._setup_sysconfig_bootloader()
+        assert sysconfig_bootloader.__setitem__.call_args_list == [
+            call('DEFAULT_APPEND', '"some-cmdline root=UUID=foo"'),
+            call(
+                'FAILSAFE_APPEND',
+                '"some-cmdline root=UUID=foo failsafe-options"'
+            ),
+            call('LOADER_LOCATION', 'none'),
+            call('LOADER_TYPE', 'grub2-efi'),
+            call('SECURE_BOOT', 'no'),
+            call('TRUSTED_BOOT', 'yes')
+        ]
+
     @patch('os.path.exists')
     def test_setup_live_image_config_custom_template(self, mock_exists):
         bootloader = Mock()
@@ -846,7 +886,7 @@ class TestBootLoaderConfigGrub2:
             True, True, 'gfxterm', None
         )
         mock_copy_grub_config_to_efi_path.assert_called_once_with(
-            'root_dir', 'earlyboot.cfg'
+            'root_dir', 'earlyboot.cfg', 'iso'
         )
 
     def test_setup_install_image_config_multiboot(self):
@@ -915,7 +955,7 @@ class TestBootLoaderConfigGrub2:
                 }
             )
             mock_mount_system.assert_called_once_with(
-                'rootdev', 'bootdev', None, None
+                'rootdev', 'bootdev', None, None, None
             )
             assert mock_Command_run.call_args_list == [
                 call(
@@ -1041,7 +1081,7 @@ class TestBootLoaderConfigGrub2:
             True, True, 'gfxterm', True
         )
         mock_copy_grub_config_to_efi_path.assert_called_once_with(
-            'root_dir', 'earlyboot.cfg'
+            'root_dir', 'earlyboot.cfg', 'iso'
         )
 
     def test_setup_iso_image_config_substitute_error(self):
@@ -1175,7 +1215,7 @@ class TestBootLoaderConfigGrub2:
                     'search_label', 'search_fs_file', 'search',
                     'search_fs_uuid', 'ls', 'normal', 'gzio', 'png', 'fat',
                     'gettext', 'font', 'minicmd', 'gfxterm', 'gfxmenu',
-                    'all_video', 'xfs', 'btrfs', 'lvm', 'luks',
+                    'all_video', 'xfs', 'btrfs', 'squash4', 'lvm', 'luks',
                     'gcry_rijndael', 'gcry_sha256', 'gcry_sha512', 'crypto',
                     'cryptodisk', 'test', 'true', 'loadenv', 'multiboot',
                     'part_gpt', 'part_msdos', 'efi_gop', 'efi_uga', 'linuxefi'
@@ -1228,7 +1268,7 @@ class TestBootLoaderConfigGrub2:
                 call('set root="cryptouuid/0815"\n'),
                 call('search --fs-uuid --set=root 0815\n'),
                 call('set prefix=($root)//grub2\n'),
-                call('configfile ($root)//grub2/grub.cfg\n')
+                call('source ($root)//grub2/grub.cfg\n')
             ]
         assert mock_command.call_args_list == [
             call(
@@ -1249,7 +1289,7 @@ class TestBootLoaderConfigGrub2:
                     'search_label', 'search_fs_file', 'search',
                     'search_fs_uuid', 'ls', 'normal', 'gzio', 'png', 'fat',
                     'gettext', 'font', 'minicmd', 'gfxterm', 'gfxmenu',
-                    'all_video', 'xfs', 'btrfs', 'lvm', 'luks',
+                    'all_video', 'xfs', 'btrfs', 'squash4', 'lvm', 'luks',
                     'gcry_rijndael', 'gcry_sha256', 'gcry_sha512', 'crypto',
                     'cryptodisk', 'test', 'true', 'loadenv', 'part_gpt',
                     'part_msdos', 'efi_gop', 'efi_uga', 'linuxefi'
@@ -1287,7 +1327,7 @@ class TestBootLoaderConfigGrub2:
                 call('set root="cryptouuid/0815"\n'),
                 call('search --fs-uuid --set=root 0815\n'),
                 call('set prefix=($root)//grub2\n'),
-                call('configfile ($root)//grub2/grub.cfg\n')
+                call('source ($root)//grub2/grub.cfg\n')
             ]
             mock_open.assert_called_once_with(
                 'root_dir/boot/efi/EFI/BOOT/grub.cfg', 'w'
@@ -1454,8 +1494,9 @@ class TestBootLoaderConfigGrub2:
     @patch('glob.iglob')
     @patch('os.chmod')
     @patch('os.stat')
+    @patch('os.path.isfile')
     def test_setup_disk_boot_images_bios_plus_efi_secure_boot_no_shim_install(
-        self, mock_stat, mock_chmod, mock_glob,
+        self, mock_isfile, mock_stat, mock_chmod, mock_glob,
         mock_exists, mock_command, mock_which, mock_get_boot_path
     ):
         # we expect the copy of shim.efi and grub.efi from the fallback
@@ -1463,6 +1504,7 @@ class TestBootLoaderConfigGrub2:
         Defaults.set_platform_name('x86_64')
         mock_get_boot_path.return_value = '/boot'
         mock_which.return_value = None
+        mock_isfile.return_value = False
         self.firmware.efi_mode = Mock(
             return_value='uefi'
         )
@@ -1492,7 +1534,7 @@ class TestBootLoaderConfigGrub2:
                     call('set root="cryptouuid/uuid"\n'),
                     call('search --fs-uuid --set=root uuid\n'),
                     call('set prefix=($root)/boot/grub2\n'),
-                    call('configfile ($root)/boot/grub2/grub.cfg\n')
+                    call('source ($root)/boot/grub2/grub.cfg\n')
                 ]
                 mock_open.assert_called_once_with(
                     'root_dir/boot/efi/EFI/BOOT/grub.cfg', 'w'
@@ -1547,8 +1589,9 @@ class TestBootLoaderConfigGrub2:
     @patch('glob.iglob')
     @patch('os.chmod')
     @patch('os.stat')
+    @patch('os.path.isfile')
     def test_setup_disk_boot_images_bios_plus_efi_secure_boot_no_shim_at_all(
-        self, mock_stat, mock_chmod, mock_glob,
+        self, mock_isfile, mock_stat, mock_chmod, mock_glob,
         mock_exists, mock_command, mock_which, mock_get_boot_path,
         mock_get_shim_loader
     ):
@@ -1559,6 +1602,7 @@ class TestBootLoaderConfigGrub2:
         Defaults.set_platform_name('x86_64')
         mock_get_boot_path.return_value = '/boot'
         mock_which.return_value = None
+        mock_isfile.return_value = False
         self.firmware.efi_mode = Mock(
             return_value='uefi'
         )
@@ -1588,7 +1632,7 @@ class TestBootLoaderConfigGrub2:
                     call('set root="cryptouuid/uuid"\n'),
                     call('search --fs-uuid --set=root uuid\n'),
                     call('set prefix=($root)/boot/grub2\n'),
-                    call('configfile ($root)/boot/grub2/grub.cfg\n')
+                    call('source ($root)/boot/grub2/grub.cfg\n')
                 ]
                 mock_open.assert_called_once_with(
                     'root_dir/boot/efi/EFI/BOOT/grub.cfg', 'w'
@@ -1688,13 +1732,13 @@ class TestBootLoaderConfigGrub2:
             ]
             assert file_handle.write.call_args_list == [
                 call('set btrfs_relative_path="yes"\n'),
-                call('search --file --set=root /boot/0xffffffff\n'),
+                call('search --file --set=root /boot/mbrid\n'),
                 call('set prefix=($root)/boot/grub2\n'),
-                call('configfile ($root)/boot/grub2/grub.cfg\n'),
+                call('source ($root)/boot/grub2/grub.cfg\n'),
                 call('set btrfs_relative_path="yes"\n'),
-                call('search --file --set=root /boot/0xffffffff\n'),
+                call('search --file --set=root /boot/mbrid\n'),
                 call('set prefix=($root)/boot/grub2\n'),
-                call('configfile ($root)/boot/grub2/grub.cfg\n'),
+                call('source ($root)/boot/grub2/grub.cfg\n'),
                 call('source /boot/grub2/grub.cfg\n')
             ]
         assert mock_Path_create.call_args_list == [
@@ -1725,7 +1769,7 @@ class TestBootLoaderConfigGrub2:
                     'search_label', 'search_fs_file', 'search',
                     'search_fs_uuid', 'ls', 'normal', 'gzio', 'png', 'fat',
                     'gettext', 'font', 'minicmd', 'gfxterm', 'gfxmenu',
-                    'all_video', 'xfs', 'btrfs', 'lvm', 'luks',
+                    'all_video', 'xfs', 'btrfs', 'squash4', 'lvm', 'luks',
                     'gcry_rijndael', 'gcry_sha256', 'gcry_sha512',
                     'crypto', 'cryptodisk', 'test', 'true', 'loadenv',
                     'part_gpt', 'part_msdos', 'biosdisk', 'vga', 'vbe',
@@ -1751,7 +1795,7 @@ class TestBootLoaderConfigGrub2:
                     'search_label', 'search_fs_file', 'search',
                     'search_fs_uuid', 'ls', 'normal', 'gzio', 'png', 'fat',
                     'gettext', 'font', 'minicmd', 'gfxterm', 'gfxmenu',
-                    'all_video', 'xfs', 'btrfs', 'lvm', 'luks',
+                    'all_video', 'xfs', 'btrfs', 'squash4', 'lvm', 'luks',
                     'gcry_rijndael', 'gcry_sha256', 'gcry_sha512',
                     'crypto', 'cryptodisk', 'test', 'true', 'loadenv',
                     'part_gpt', 'part_msdos', 'efi_gop', 'efi_uga', 'linuxefi'
@@ -1801,9 +1845,9 @@ class TestBootLoaderConfigGrub2:
 
             assert file_handle.write.call_args_list == [
                 call('set btrfs_relative_path="yes"\n'),
-                call('search --file --set=root /boot/0xffffffff\n'),
+                call('search --file --set=root /boot/mbrid\n'),
                 call('set prefix=($root)/boot/grub2\n'),
-                call('configfile ($root)/boot/grub2/grub.cfg\n'),
+                call('source ($root)/boot/grub2/grub.cfg\n'),
                 call('source /boot/grub2/grub.cfg\n')
             ]
             assert mock_open.call_args_list == [
@@ -1838,12 +1882,14 @@ class TestBootLoaderConfigGrub2:
     @patch('glob.iglob')
     @patch('os.chmod')
     @patch('os.stat')
+    @patch('os.path.isfile')
     def test_setup_install_boot_images_efi_secure_boot(
-        self, mock_stat, mock_chmod, mock_glob,
+        self, mock_isfile, mock_stat, mock_chmod, mock_glob,
         mock_exists, mock_command, mock_supports_bios_modules
     ):
         Defaults.set_platform_name('x86_64')
         mock_supports_bios_modules.return_value = False
+        mock_isfile.return_value = False
         self.os_exists['root_dir'] = True
         self.firmware.efi_mode = Mock(
             return_value='uefi'
@@ -1869,9 +1915,9 @@ class TestBootLoaderConfigGrub2:
                 )
                 assert file_handle.write.call_args_list == [
                     call('set btrfs_relative_path="yes"\n'),
-                    call('search --file --set=root /boot/0xffffffff\n'),
+                    call('search --file --set=root /boot/mbrid\n'),
                     call('set prefix=($root)/boot/grub2\n'),
-                    call('configfile ($root)/boot/grub2/grub.cfg\n'),
+                    call('source ($root)/boot/grub2/grub.cfg\n'),
                     call('source /boot/grub2/grub.cfg\n')
                 ]
                 assert mock_open.call_args_list == [
@@ -1899,7 +1945,7 @@ class TestBootLoaderConfigGrub2:
                     call(
                         [
                             'cp', 'root_dir/usr/lib64/efi/grub.efi',
-                            'root_dir/EFI/BOOT/grub.efi'
+                            'root_dir/EFI/BOOT/grubx64.efi'
                         ]
                     ),
                     call(
