@@ -16,7 +16,7 @@ class TestMarkupXML:
     def setup_method(self, cls):
         self.setup()
 
-    @patch('anymarkup.parse_file')
+    @patch('anymarkup_core.parse_file')
     def test_raises_markup_conversion_error(self, mock_anymarkup_parse_file):
         mock_anymarkup_parse_file.side_effect = Exception
         with raises(KiwiDescriptionInvalid):
