@@ -47,7 +47,6 @@ class TestRootImportOCI:
     def test_sync_data(self, mock_OCI, mock_path, mock_md5, mock_compress):
         oci = Mock()
         mock_OCI.new.return_value = oci
-        md5 = Mock()
         mock_md5.return_value = Mock()
 
         uncompress = Mock()
@@ -63,9 +62,39 @@ class TestRootImportOCI:
             'root_dir'
         )
         mock_md5.assert_called_once_with('root_dir/image/imported_root')
-        md5.md5.called_once_with('root_dir/image/imported_root.md5')
         uncompress.get_format.assert_called_once_with()
 
+    @patch('kiwi.system.root_import.oci.Compress')
+    @patch('kiwi.system.root_import.oci.Path.create')
+    @patch('kiwi.system.root_import.oci.Path.rename')
+    @patch('kiwi.system.root_import.oci.MountManager')
+    @patch('kiwi.system.root_import.oci.OCI')
+    def test_overlay_data(
+        self, mock_OCI, mock_MountManager, mock_path_rename,
+        mock_path_create, mock_compress
+    ):
+        oci = Mock()
+        mock_OCI.new.return_value = oci
+
+        self.oci_import.overlay_data()
+
+        mock_OCI.new.assert_called_once_with()
+
+        oci.import_container_image.assert_called_once_with(
+            f'oci-archive:{mock_compress.return_value.uncompressed_filename}'
+        )
+        oci.unpack.assert_called_once_with()
+        oci.import_rootfs.assert_called_once_with(
+            'root_dir'
+        )
+        mock_path_rename.assert_called_once_with(
+            'root_dir', 'root_dir_ro'
+        )
+        mock_path_create.assert_called_once_with('root_dir')
+        mock_MountManager.return_value.overlay_mount.assert_called_once_with(
+            'root_dir_ro'
+        )
+
     @patch('kiwi.system.root_import.oci.Compress')
     @patch('kiwi.system.root_import.base.Checksum')
     @patch('kiwi.system.root_import.oci.Path.create')
@@ -75,7 +104,6 @@ class TestRootImportOCI:
     ):
         oci = Mock()
         mock_OCI.new.return_value = oci
-        md5 = Mock()
         mock_md5.return_value = Mock()
 
         uncompress = Mock()
@@ -91,7 +119,6 @@ class TestRootImportOCI:
             'root_dir'
         )
         mock_md5.assert_called_once_with('root_dir/image/imported_root')
-        md5.md5.called_once_with('root_dir/image/imported_root.md5')
         uncompress.get_format.assert_called_once_with()
         uncompress.uncompress.assert_called_once_with(True)
 
@@ -105,7 +132,6 @@ class TestRootImportOCI:
         mock_exists.return_value = True
         oci = Mock()
         mock_OCI.new.return_value = oci
-        md5 = Mock()
         mock_md5.return_value = Mock()
         with patch.dict('os.environ', {'HOME': '../data'}):
             oci_import = RootImportOCI(
@@ -124,4 +150,3 @@ class TestRootImportOCI:
                 'root_dir'
             )
             mock_md5.assert_called_once_with('root_dir/image/imported_root')
-            md5.md5.called_once_with('root_dir/image/imported_root.md5')
