@@ -60,6 +60,7 @@ class TestXMLState:
         self.bootloader.get_targettype.return_value = 'some-target'
         self.bootloader.get_console.return_value = 'some-console'
         self.bootloader.get_serial_line.return_value = 'some-serial'
+        self.bootloader.get_use_disk_password.return_value = True
 
     def setup_method(self, cls):
         self.setup()
@@ -116,7 +117,7 @@ class TestXMLState:
     @patch('kiwi.xml_state.XMLState.get_preferences_sections')
     def test_get_default_package_manager(self, mock_preferences):
         mock_preferences.return_value = []
-        assert self.state.get_package_manager() == 'dnf'
+        assert self.state.get_package_manager() == 'dnf4'
 
     def test_get_image_version(self):
         assert self.state.get_image_version() == '1.13.2'
@@ -131,6 +132,12 @@ class TestXMLState:
         assert self.no_image_packages_boot_state.get_bootstrap_packages() == [
             'patterns-openSUSE-base'
         ]
+        self.state.get_package_manager = Mock(
+            return_value="dnf4"
+        )
+        assert self.state.get_bootstrap_packages() == [
+            'dnf', 'filesystem',
+        ]
 
     def test_get_system_packages(self):
         assert self.state.get_system_packages() == [
@@ -379,6 +386,7 @@ class TestXMLState:
         volume_type = namedtuple(
             'volume_type', [
                 'name',
+                'parent',
                 'size',
                 'realpath',
                 'mountpoint',
@@ -390,7 +398,7 @@ class TestXMLState:
         )
         assert state.get_volumes() == [
             volume_type(
-                name='myroot', size='freespace:500',
+                name='myroot', parent='', size='freespace:500',
                 realpath='/',
                 mountpoint=None, fullsize=False,
                 label=None,
@@ -406,6 +414,7 @@ class TestXMLState:
         volume_type = namedtuple(
             'volume_type', [
                 'name',
+                'parent',
                 'size',
                 'realpath',
                 'mountpoint',
@@ -417,7 +426,7 @@ class TestXMLState:
         )
         assert state.get_volumes() == [
             volume_type(
-                name='usr_lib', size='size:1024',
+                name='usr_lib', parent='', size='size:1024',
                 realpath='usr/lib',
                 mountpoint='usr/lib',
                 fullsize=False,
@@ -426,7 +435,7 @@ class TestXMLState:
                 is_root_volume=False
             ),
             volume_type(
-                name='LVRoot', size='freespace:500',
+                name='LVRoot', parent='', size='freespace:500',
                 realpath='/',
                 mountpoint=None, fullsize=False,
                 label=None,
@@ -434,7 +443,7 @@ class TestXMLState:
                 is_root_volume=True
             ),
             volume_type(
-                name='etc_volume', size='freespace:30',
+                name='etc_volume', parent='', size='freespace:30',
                 realpath='etc',
                 mountpoint='etc', fullsize=False,
                 label=None,
@@ -442,7 +451,7 @@ class TestXMLState:
                 is_root_volume=False
             ),
             volume_type(
-                name='bin_volume', size=None,
+                name='bin_volume', parent='', size=None,
                 realpath='/usr/bin',
                 mountpoint='/usr/bin', fullsize=True,
                 label=None,
@@ -450,7 +459,7 @@ class TestXMLState:
                 is_root_volume=False
             ),
             volume_type(
-                name='LVSwap', size='size:128',
+                name='LVSwap', parent='', size='size:128',
                 realpath='swap',
                 mountpoint=None, fullsize=False,
                 label='SWAP',
@@ -466,6 +475,7 @@ class TestXMLState:
         volume_type = namedtuple(
             'volume_type', [
                 'name',
+                'parent',
                 'size',
                 'realpath',
                 'mountpoint',
@@ -477,14 +487,14 @@ class TestXMLState:
         )
         assert state.get_volumes() == [
             volume_type(
-                name='LVRoot', size=None, realpath='/',
+                name='LVRoot', parent='', size=None, realpath='/',
                 mountpoint=None, fullsize=True,
                 label=None,
                 attributes=[],
                 is_root_volume=True
             ),
             volume_type(
-                name='LVSwap', size='size:128',
+                name='LVSwap', parent='', size='size:128',
                 realpath='swap',
                 mountpoint=None, fullsize=False,
                 label='SWAP',
@@ -502,6 +512,7 @@ class TestXMLState:
         volume_type = namedtuple(
             'volume_type', [
                 'name',
+                'parent',
                 'size',
                 'realpath',
                 'mountpoint',
@@ -513,21 +524,21 @@ class TestXMLState:
         )
         assert state.get_volumes() == [
             volume_type(
-                name='usr', size=None, realpath='usr',
+                name='usr', parent='', size=None, realpath='usr',
                 mountpoint='usr', fullsize=True,
                 label=None,
                 attributes=[],
                 is_root_volume=False
             ),
             volume_type(
-                name='LVRoot', size='freespace:30', realpath='/',
+                name='LVRoot', parent='', size='freespace:30', realpath='/',
                 mountpoint=None, fullsize=False,
                 label=None,
                 attributes=[],
                 is_root_volume=True
             ),
             volume_type(
-                name='LVSwap', size='size:128',
+                name='LVSwap', parent='', size='size:128',
                 realpath='swap',
                 mountpoint=None, fullsize=False,
                 label='SWAP',
@@ -1014,6 +1025,13 @@ class TestXMLState:
         mock_bootloader.return_value = [self.bootloader]
         assert self.state.get_build_type_bootloader_name() == 'some-loader'
 
+    @patch('kiwi.xml_parse.type_.get_bootloader')
+    def test_get_build_type_bootloader_use_disk_password(self, mock_bootloader):
+        mock_bootloader.return_value = [None]
+        assert self.state.get_build_type_bootloader_use_disk_password() is False
+        mock_bootloader.return_value = [self.bootloader]
+        assert self.state.get_build_type_bootloader_use_disk_password() is True
+
     @patch('kiwi.xml_parse.type_.get_bootloader')
     def test_get_build_type_bootloader_console(self, mock_bootloader):
         mock_bootloader.return_value = [self.bootloader]
@@ -1099,7 +1117,8 @@ class TestXMLState:
         assert self.state.get_luks_format_options() == [
             '--type', 'luks2',
             '--cipher', 'aes-gcm-random',
-            '--integrity', 'aead'
+            '--integrity', 'aead',
+            '--pbkdf', 'pbkdf2'
         ]
 
     def test_get_bootstrap_package_name(self):
@@ -1117,3 +1136,7 @@ class TestXMLState:
         assert state.get_bootloader_config_options() == [
             '--joe', '-x'
         ]
+
+    def test_get_btrfs_root_is_subvolume(self):
+        assert self.state.build_type.get_btrfs_root_is_subvolume() is \
+            None
